ConfigManager

Struct ConfigManager 

pub struct ConfigManager {
    pub dirty: bool,
    /* private fields */
}
Watches config.toml for changes via periodic timestamp polling.

Call ConfigManager::poll once per frame in the main loop. When the file has been modified externally dirty is set to true and the new config is available via ConfigManager::config.

Fields

dirty: bool

Set to true by poll when the file changed.

Implementations

Source

impl ConfigManager

pub fn new(dir: PathBuf) -> Self

Create a new manager, immediately loading the config from dir.

pub fn poll(&mut self)

Re-read config from disk. Call this once per frame.

pub fn ack(&mut self)

Acknowledge the dirty flag (call after applying changes).

pub fn config(&self) -> &Config

pub fn error(&self) -> Option<&str>

Error message from the last failed config load/parse, if any.

pub fn save_theme(&mut self, theme_name: &str)

Update the theme field and immediately persist. When selecting a built-in theme, custom overrides are cleared so they don’t leak into the newly chosen theme.

pub fn save_custom_theme(&mut self, colors: CustomThemeColors)

Set custom theme colour overrides in config and persist.

pub fn tick_rate(&self) -> Duration

pub fn set_tick_rate(&mut self, duration: Duration)

pub fn clear_custom_theme(&mut self)

Remove custom theme colour overrides from config and persist.